==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Valitse viiva, kaari tai ympyrä</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Etäisyys:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Numero:</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Poikkeama (etäisyydellä)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Poikkeama viivassa, kaaressa, ympyrässä tai ellipsissä</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Valitse viiva, kaari, ympyrä tai ellipsi</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Valitse viiva, kaari tai ympyrä</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Etäisyys:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Numero:</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Poikkeama (etäisyydellä)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Poikkeama viivassa, kaaressa, ympyrässä tai ellipsissä</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Valitse viiva, kaari, ympyrä tai ellipsi</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
</TS>
